@@ -232,7 +232,7 @@ KNotesApp::KNotesApp(QWidget *parent)
     connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved,
             this, &KNotesApp::slotItemRemoved);
 
-    connect(mNoteRecorder->changeRecorder(), QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Akonadi::ChangeRecorder::collectionChanged),
+    connect(mNoteRecorder->changeRecorder(), qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Akonadi::ChangeRecorder::collectionChanged),
             this, &KNotesApp::slotCollectionChanged);
 
     connect(qApp, &QGuiApplication::commitDataRequest,
@@ -580,7 +580,7 @@ void KNotesApp::slotPreferences()
 {
     // create a new preferences dialog...
     KNoteConfigDialog *dialog = new KNoteConfigDialog(i18n("Settings"), this);
-    connect(dialog, QOverload<>::of(&KCMultiDialog::configCommitted), this, &KNotesApp::slotConfigUpdated);
+    connect(dialog, qOverload<>(&KCMultiDialog::configCommitted), this, &KNotesApp::slotConfigUpdated);
     dialog->show();
 }
 
@@ -632,7 +632,8 @@ void KNotesApp::slotConfigureAccels()
             QHashIterator<Akonadi::Item::Id, KNote *> i(mNotes);
             while (i.hasNext()) {
                 i.next();
-                foreach (QAction *action, actionCollection->actions()) {
+                const auto lst = actionCollection->actions();
+                for (QAction *action : lst) {
                     QAction *toChange = i.value()->actionCollection()->action(action->objectName());
                     if (toChange) {
                         toChange->setShortcuts(action->shortcuts());
